==> payara-embedded-all-5.201-sources.jar: fish/payara/monitoring/configuration/MonitoringConsoleConfiguration.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2020 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.monitoring.configuration;

import java.beans.PropertyVetoException;
import java.util.List;

import org.jvnet.hk2.config.Attribute;
import org.jvnet.hk2.config.Configured;
import org.jvnet.hk2.config.Element;

import com.sun.enterprise.config.serverbeans.DomainExtension;

/**
 * Configuration for the monitoring console core.
 * This is first of all the data and watch collection and evaluation.
 * 
 * @author Jan Bernitt
 * @since 5.201
 */
@Configured
public interface MonitoringConsoleConfiguration extends DomainExtension {

    /**
     * Note that this is not reflecting whether or not the monitoring data is collected.
     * This is controlled by the general monitoring configuration.
     * 
     * @return True, if monitoring console web-app is deployed, else false.
     */
    @Attribute(defaultValue = "false", dataType = Boolean.class)
    String getEnabled();
    void setEnabled(String value) throws PropertyVetoException;

    /**
     * @return Names of the watches that are disabled (this includes collected and custom watches)
     */
    @Element
    List<String> getDisabledWatchNames();

    /**
     * @return Names of custom watches (so collected watches are not included)
     */
    @Element
    List<String> getCustomWatchNames();

    /**
     * @return JSON values of the custom watches (index is same in {@link #getCustomWatchNames()})
     */
    @Element
    List<String> getCustomWatchValues();

}

==> payara-embedded-all-5.2020.4-sources.jar: fish/payara/monitoring/configuration/MonitoringConsoleConfiguration.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2020 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.monitoring.configuration;

import java.beans.PropertyVetoException;
import java.util.List;

import org.jvnet.hk2.config.Attribute;
import org.jvnet.hk2.config.Configured;
import org.jvnet.hk2.config.Element;

import com.sun.enterprise.config.serverbeans.DomainExtension;

/**
 * Configuration for the monitoring console core.
 * This is first of all the data and watch collection and evaluation.
 *
 * @author Jan Bernitt
 * @since 5.201
 */
@Configured
public interface MonitoringConsoleConfiguration extends DomainExtension {

    /**
     * Note that this is not reflecting whether or not the monitoring data is collected.
     * This is controlled by the general monitoring configuration.
     *
     * @return True, if monitoring console web-app is deployed, else false.
     */
    @Attribute(defaultValue = "false", dataType = Boolean.class)
    String getEnabled();
    void setEnabled(String value) throws PropertyVetoException;

    /**
     * @return Names of the watches that are disabled (this includes collected and custom watches)
     */
    @Element
    List<String> getDisabledWatchNames();

    /**
     * @return Names of custom watches (so collected watches are not included)
     */
    @Element
    List<String> getCustomWatchNames();

    /**
     * @return JSON values of the custom watches (index is same in {@link #getCustomWatchNames()})
     */
    @Element
    List<String> getCustomWatchValues();

    /**
     * @return Names of MC (client) pages
     */
    @Element
    List<String> getPageNames();

    /**
     * @return JSON values of the MC (client) pages (index is same in {@link #getPageNames()})
     */
    @Element
    List<String> getPageValues();

}
